MoveEventResult

Enum MoveEventResult 

pub enum MoveEventResult {
    Fail,
    Stop,
    Advance,
}
The result of a move event, which indicates how the rest of the move should be handled.

Variants



Fail

Fail the move immediately.



Stop

Stop the move, but the move did not necessarily fail.



Advance

Continue the move.

Implementations

Source

impl MoveEventResult

pub fn advance(&self) -> bool

Keep executing the move?

pub fn failed(&self) -> bool

Fail the move immediately?

pub fn combine(&self, other: Self) -> Self

Combines two results into one.