MoveOutcomeOnTarget

Enum MoveOutcomeOnTarget 

pub enum MoveOutcomeOnTarget {
    Unknown,
    Failure,
    HitSubstitute,
    Success,
    Damage(u16),
}
The outcome of a move used on a single target in a single turn of battle.

Differs from MoveOutcome in that it roughly tracks the effect a move had on a single target, rather than the outcome of the use of the move as a whole.

Variants



Unknown

It is unknown how the move affected the target.



Failure

The move failed to do anything to the target.



HitSubstitute

The move hit a Substitute.



Success

The move successfully hit the target.



Damage(u16)

The move successfully dealt damage to the target.

Implementations

Source

impl MoveOutcomeOnTarget

pub fn hit(&self) -> bool

Did the move hit anything (including a Substitute)?

pub fn hit_target(&self) -> bool

Did the move hit the target as intended?

pub fn failed(&self) -> bool

Did the move fail?

pub fn damage(&self) -> u16

How much damage the move dealt to the target.

pub fn combine(&self, other: Self) -> Self

Combines two move outcomes into one.

Important when moves do multiple things and we must determine the outcome on the target as a whole.