PlayerEffectContext

Struct PlayerEffectContext 

pub struct PlayerEffectContext<'effect, 'context, 'battle, 'data>
where 'data: 'battle, 'battle: 'context, 'context: 'effect,
{ /* private fields */ }
The context of an Effect applying on a Player in a battle.

See Context for more information on how context objects work.

Implementations

Source

impl<'effect, 'context, 'battle, 'data> PlayerEffectContext<'effect, 'context, 'battle, 'data>

pub fn as_battle_context<'side_effect>( &'side_effect self, ) -> &'side_effect Context<'battle, 'data>

Returns a reference to the inner Context.

pub fn as_battle_context_mut<'side_effect>( &'side_effect mut self, ) -> &'side_effect mut Context<'battle, 'data>

Returns a mutable reference to the inner Context.

pub fn as_effect_context<'side_effect>( &'side_effect self, ) -> &'side_effect EffectContext<'context, 'battle, 'data>

Returns a reference to the inner EffectContext.

pub fn as_effect_context_mut<'side_effect>( &'side_effect mut self, ) -> &'side_effect mut EffectContext<'context, 'battle, 'data>

Returns a mutable reference to the inner EffectContext.

pub fn source_context<'applying_effect>( &'applying_effect mut self, ) -> Result<Option<MonContext<'applying_effect, 'applying_effect, 'applying_effect, 'battle, 'data>>>

Creates a new MonContext for the effect source, scoped to the lifetime of this context.

pub fn forward_player_effect_context<'side_effect>( &'side_effect mut self, effect_handle: EffectHandle, ) -> Result<PlayerEffectContext<'side_effect, 'side_effect, 'battle, 'data>>

Creates a new SideEffectContext for the same target side but different effect, using this effect as its source, scoped to the lifetime of this context.

pub fn source_side_effect_context<'side_effect>( &'side_effect mut self, ) -> Result<Option<SideEffectContext<'side_effect, 'side_effect, 'battle, 'data>>>

Creates a new SideEffectContext for the source effect with the same target side, scoped to the lifetime of this context.

pub fn battle(&self) -> &CoreBattle<'data>

Returns a reference to the CoreBattle.

pub fn battle_mut(&mut self) -> &mut CoreBattle<'data>

Returns a mutable reference to the CoreBattle.

pub fn effect_handle(&self) -> &EffectHandle

Returns the EffectHandle for the Effect.

pub fn effect(&self) -> &Effect<'_>

Returns a reference to the Effect.

pub fn effect_mut(&mut self) -> &mut Effect<'context>

Returns a mutable reference to the Effect.

pub fn source_effect_handle(&self) -> Option<&EffectHandle>

Returns a reference to the source EffectHandle, if it exists.

pub fn player(&self) -> &Player

Returns a reference to the target Player.

pub fn player_mut(&mut self) -> &mut Player

Returns a mutable reference to the target Player.

pub fn source_handle(&self) -> Option<MonHandle>

Returns the MonHandle for the source Mon, if one exists.

pub fn has_source(&self) -> bool

Checks if the effect has a source Mon.

pub fn source(&self) -> Option<&Mon>

Returns a reference to the source Mon, if one exists.

pub fn source_mut(&mut self) -> Option<&mut Mon>

Returns a mutable reference to the source Mon, if one exists.