LruCache

Struct LruCache 

pub struct LruCache<K, V> { /* private fields */ }
An LRU (least-recently-used) cache.

Implemented by maintaining a doubly-linked list of cache entries. On access, entries are moved to the head of list. Once the cache reaches capacity, entries at the back of the list will be evicted first to make room for newer entries.

Implementations

Source

impl<K, V> LruCache<K, V>
where K: Eq + Hash,

pub fn new(capacity: usize) -> Self

Creates a new LRU cache with the given capacity.

pub fn capacity(&self) -> usize

The capacity of the cache.

pub fn len(&self) -> usize

The length of the map.

pub fn put(&mut self, key: K, value: V) -> Option<V>

Puts a key-value pair into the cache.

If the key already exists in the cache, it is updated and the old value is returned. Otherwise, None is returned.

pub fn push(&mut self, key: K, value: V) -> Option<(K, V)>

Pushes a key-value pair into the cache.

If the key already exists in the cache or another entry is removed (due to capacity), then the old key-value pair is returned. Otherwise, returns None.

pub fn contains_key<'a, L>(&'a self, key: &L) -> bool
where K: Borrow<L>, L: Eq + Hash + ?Sized,

Checks if the given key is contained in the cache.

pub fn get<'a, L>(&'a mut self, key: &L) -> Option<&'a V>
where K: Borrow<L>, L: Eq + Hash + ?Sized,

Returns a reference to the value associated with the given key.

Moves the key to the head of the LRU list if it exists. Otherwise, returns None.

pub fn get_mut<'a, L>(&'a mut self, key: &L) -> Option<&'a mut V>
where K: Borrow<L>, L: Eq + Hash + ?Sized,

Returns a mutable reference to the value associated with the given key.

Moves the key to the head of the LRU list if it exists. Otherwise, returns None.

pub fn iter(&self) -> Iter<'_, K, V>

Returns an iterator visiting all entries in most-recently used order.

pub fn iter_mut(&self) -> IterMut<'_, K, V>

Returns an iterator visiting all entries in most-recently used order, with a mutable reference to the value.