ValueRefToStoredValue

Struct ValueRefToStoredValue 

pub struct ValueRefToStoredValue<'eval> { /* private fields */ }
A reference to some stored Value.

Assumes the underlying value is stored in an ElementRef.

Implementations

Source

impl<'eval> ValueRefToStoredValue<'eval>

pub fn new( element_ref: Option<ElementRef<'eval, Value>>, value: ValueRef<'eval>, ) -> Self

Creates a new reference to a stored value.

pub fn value_type(&self) -> ValueType

The type of the value.

pub fn to_owned(&self) -> Value

Converts the reference to a Value, which is guaranteed to contain no references.

pub fn value_ref(&self) -> &ValueRef<'eval>

Returns a reference to the internal reference.

pub fn list_index(&self, index: usize) -> Option<Self>

Returns the list element at the given index.

Copies the underlying ElementRef to the indexed value.