pub enum MoveEventResult {
Fail,
Stop,
Advance,
}Expand description
The result of a move event, which indicates how the rest of the move should be handled.
Variants
Fail
Fail the move immediately.
Stop
Stop the move, but the move did not necessarily fail.
Advance
Continue the move.
Implementations