pub enum MoveOutcomeOnTarget {
Unknown,
Failure,
HitSubstitute,
Success,
Damage(u16),
}Expand description
The outcome of a move used on a single target in a single turn of battle.
Differs from MoveOutcome in that it roughly tracks the effect a move had on a single target,
rather than the outcome of the use of the move as a whole.
Variants
Unknown
It is unknown how the move affected the target.
Failure
The move failed to do anything to the target.
HitSubstitute
The move hit a Substitute.
Success
The move successfully hit the target.
Damage(u16)
The move successfully dealt damage to the target.
Implementations
Sourceimpl MoveOutcomeOnTarget
impl MoveOutcomeOnTarget
Sourcepub fn hit_target(&self) -> bool
pub fn hit_target(&self) -> bool
Did the move hit the target as intended?