pub struct ValueRefToStoredValue<'eval> { /* private fields */ }Expand description
A reference to some stored Value.
Assumes the underlying value is stored in an ElementRef.
Implementations
Sourceimpl<'eval> ValueRefToStoredValue<'eval>
impl<'eval> ValueRefToStoredValue<'eval>
Sourcepub fn new(
element_ref: Option<ElementRef<'eval, Value>>,
value: ValueRef<'eval>,
) -> Self
pub fn new( element_ref: Option<ElementRef<'eval, Value>>, value: ValueRef<'eval>, ) -> Self
Creates a new reference to a stored value.
Sourcepub fn value_type(&self) -> ValueType
pub fn value_type(&self) -> ValueType
The type of the value.
Sourcepub fn to_owned(&self) -> Value
pub fn to_owned(&self) -> Value
Converts the reference to a Value, which is guaranteed to contain no references.
Sourcepub fn list_index(&self, index: usize) -> Option<Self>
pub fn list_index(&self, index: usize) -> Option<Self>
Returns the list element at the given index.
Copies the underlying ElementRef to the indexed value.